program eels_boson

! ******************************************************************
! *                                                                *
! * Does the calculation for one fixed example for profiling       *
! * It does not do any file IO                                     *
! *                                                                *
! ******************************************************************

  implicit none

  double precision :: e0, theta, phia, phib, wmin, wmax, dw
  integer :: i, j, jos, k, l, layers, neps, nper, nw
  logical :: user
  character (len = 72) :: comment(2)
  character (len = 10) :: contrl, mode
  double precision, allocatable :: xout(:), yout(:)
  integer :: nout

  double precision, allocatable :: thick(:), epsinf(:), osc(:, :)
  integer, allocatable :: nos(:)
  character (len = 10), allocatable :: name(:)
  double precision, allocatable :: wn_array(:), f(:)

  integer :: old_size_1, old_size_2
  double precision, allocatable :: tmp_osc(:, :)

  double precision :: asym, emax, emin, gauss, t, width
  integer :: ioStatus

! *** set spectrometer parameters

! impact energy (ev)
  e0 = 4.0
! incidence angle (%)
  theta = 60.0
! angular apertures of the elliptic detector (%)
  phia = 1.8
  phib = 1.8
! energy-loss interval and step size (cm**-1)
  wmin =  50.0
  wmax = 700.0
  dw =     2.0
! comment lines
  comment(1) = 'WFW: MnO layer on metal'
  comment(1) = ''

! *** set target specifications

  layers = 2
  nper = 1
  mode = ''
  user = layers == 0
  if (.not. user) then
    neps = layers
    if (nper == -1) then
      neps = layers + 1
      nper = 1
    endif
    jos = 0
    allocate (name(neps), thick(neps), epsinf(neps), nos(neps), osc(3,neps))
    name(1)   = 'MnO'
    thick(1)  = 994.0
    epsinf(1) = 4.95
    nos(1)    = 1

    osc(1, 1) = 269.0
    osc(2, 1) =  16.0
    osc(3, 1) =   5.0E-02
    
    name(2)   = 'Platinum'
    thick(2)  = 1000.00
    epsinf(2) = 8.90
    nos(2)    = 1
    
    osc(1, 2) = 160000.0
    osc(2, 2) = -1
    osc(3, 2) =  12.0E-02 
    
    contrl = ''
  endif

  nw = 1 + int((wmax - wmin) / dw)
  allocate (wn_array(nw), f(nw))

  do i = 1, 100
  call doeels(e0, theta, phia, phib, wmin, wmax, dw, comment, size(comment),   &
              layers, neps, nper, name, size(name), thick, epsinf, nos, osc, size(osc, 2),&
              contrl, mode, wn_array, f, size(wn_array))
  enddo
  
! target temperature (Kelvin)
  t = 300.0
! width of the instrumental response (cm**-1)
  width = 25.0
! fraction of gaussian for the instrumental response
  gauss = 0.5
! asymmetry of the instrumental response
  asym = 0.3
! lower and upper energy losses for this computation (cm**-1)
  emin = -500.0
  emax = 1200.0

! length calculation for xout, yout.
! not done yet.
  nout = 2**14
  allocate (xout(nout))
  allocate (yout(nout))

  do i = 1, 100
  call doboson(t, width, gauss, asym, emin, emax, &
               wmin, wmax, nw, f, xout, yout, nout)
  enddo

  deallocate (xout, yout)

  stop 'Successful end!'

101 format(i3, ' layer(s), nper = ', i2//'   l', 2x, 'material', 7x,  &
      'thickness', 5x, 'epsinf', 4x, 'wto , wp', 5x, 'q', 7x, 'gam/wto')
102 format(a10, d15.5)
103 format(1x, 72('-'))
104 format(1x, i3, 2x, a10, g15.3, f10.4, f12.4, f10.4, f9.4)
105 format(31x, f10.4, f12.4, f10.4, f9.4)
106 format(45x, 'wlo , wp', 5x, 'q', 7x, 'gam/wlo')
107 format(45x, 28('-'))
108 format(41x, f12.4, f10.4, f9.4)
end program eels_boson
